from ..todo import LogToDo


def log(response, status_code, index: str, doc, params=None, headers=None):
    metadata = response.get('metadata')
    status = response.get('status')
    todo = LogToDo(response, status_code, index, doc, headers, params)
    results = todo.process()
    transaction = {
        'status': status,
        'index': index,
    }
    for result in results:
        transaction.update(result)
    metadata.update({
        'transaction': transaction
    })
    return response, status_code



from rest_framework import pagination
from django.http import JsonResponse
import json


class Pagination(pagination.PageNumberPagination):
    def get_paginated_response(self, response):
        return JsonResponse({
            "count": self.page.paginator.count,
            'current': self.page.number,
            **response
        })



from django.conf import settings

SENTRY_ALLOWED_ALL = getattr(settings, 'SENTRY_ALLOWED_ALL', False)
SENTRY_ALLOWED_STATUS = getattr(settings, 'SENTRY_ALLOWED_STATUS', [])


def validate_status(status_code):
    if SENTRY_ALLOWED_ALL:
        return True
    if status_code in SENTRY_ALLOWED_STATUS:
        return True
    return False



from ..multiprocessing import Todo
from ..sentry.commands import SentryCommand
from ..elasticsearch.commands import ElasticSearchCommand


class LogToDo(Todo):
    def __init__(self, response, status_code, index, doc, headers, params):
        sentry_cmd = SentryCommand(response, status_code)
        elastic_cmd = ElasticSearchCommand(response, status_code, index, doc, headers, params)
        commands = [sentry_cmd, elastic_cmd]
        super(LogToDo, self).__init__(commands)
